==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/managednetworkfabric/kotlin/inputs/ActionIpCommunityPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.managednetworkfabric.kotlin.inputs

import com.pulumi.azurenative.managednetworkfabric.inputs.ActionIpCommunityPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * IP Community Properties.
 * @property add IP Community ID list properties.
 * @property delete IP Community ID list properties.
 * @property set IP Community ID list properties.
 */
public data class ActionIpCommunityPropertiesArgs(
    public val add: Output<IpCommunityIdListArgs>? = null,
    public val delete: Output<IpCommunityIdListArgs>? = null,
    public val `set`: Output<IpCommunityIdListArgs>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.managednetworkfabric.inputs.ActionIpCommunityPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.managednetworkfabric.inputs.ActionIpCommunityPropertiesArgs =
        com.pulumi.azurenative.managednetworkfabric.inputs.ActionIpCommunityPropertiesArgs.builder()
            .add(add?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .delete(delete?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .`set`(`set`?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [ActionIpCommunityPropertiesArgs].
 */
@PulumiTagMarker
public class ActionIpCommunityPropertiesArgsBuilder internal constructor() {
    private var add: Output<IpCommunityIdListArgs>? = null

    private var delete: Output<IpCommunityIdListArgs>? = null

    private var `set`: Output<IpCommunityIdListArgs>? = null

    /**
     * @param value IP Community ID list properties.
     */
    @JvmName("jshnmaoaewmowojb")
    public suspend fun add(`value`: Output<IpCommunityIdListArgs>) {
        this.add = value
    }

    /**
     * @param value IP Community ID list properties.
     */
    @JvmName("mnqwowcxwlmynsry")
    public suspend fun delete(`value`: Output<IpCommunityIdListArgs>) {
        this.delete = value
    }

    /**
     * @param value IP Community ID list properties.
     */
    @JvmName("jyunmimitpvhwxys")
    public suspend fun `set`(`value`: Output<IpCommunityIdListArgs>) {
        this.`set` = value
    }

    /**
     * @param value IP Community ID list properties.
     */
    @JvmName("lvxdbocagndmqjoy")
    public suspend fun add(`value`: IpCommunityIdListArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.add = mapped
    }

    /**
     * @param argument IP Community ID list properties.
     */
    @JvmName("vwcuxpuekiyrolei")
    public suspend fun add(argument: suspend IpCommunityIdListArgsBuilder.() -> Unit) {
        val toBeMapped = IpCommunityIdListArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.add = mapped
    }

    /**
     * @param value IP Community ID list properties.
     */
    @JvmName("dqkpbcubyxfgkkwd")
    public suspend fun delete(`value`: IpCommunityIdListArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.delete = mapped
    }

    /**
     * @param argument IP Community ID list properties.
     */
    @JvmName("xpnjhqrfwcoormls")
    public suspend fun delete(argument: suspend IpCommunityIdListArgsBuilder.() -> Unit) {
        val toBeMapped = IpCommunityIdListArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.delete = mapped
    }

    /**
     * @param value IP Community ID list properties.
     */
    @JvmName("pxiqbsdodrjybatv")
    public suspend fun `set`(`value`: IpCommunityIdListArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`set` = mapped
    }

    /**
     * @param argument IP Community ID list properties.
     */
    @JvmName("ncgqfakxctvqmdsa")
    public suspend fun `set`(argument: suspend IpCommunityIdListArgsBuilder.() -> Unit) {
        val toBeMapped = IpCommunityIdListArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.`set` = mapped
    }

    internal fun build(): ActionIpCommunityPropertiesArgs = ActionIpCommunityPropertiesArgs(
        add = add,
        delete = delete,
        `set` = `set`,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/managednetworkfabric/kotlin/inputs/ActionIpCommunityPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.managednetworkfabric.kotlin.inputs

import com.pulumi.azurenative.managednetworkfabric.inputs.ActionIpCommunityPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * IP Community Properties.
 * @property add IP Community ID list properties.
 * @property delete IP Community ID list properties.
 * @property set IP Community ID list properties.
 */
public data class ActionIpCommunityPropertiesArgs(
    public val add: Output<IpCommunityIdListArgs>? = null,
    public val delete: Output<IpCommunityIdListArgs>? = null,
    public val `set`: Output<IpCommunityIdListArgs>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.managednetworkfabric.inputs.ActionIpCommunityPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.managednetworkfabric.inputs.ActionIpCommunityPropertiesArgs =
        com.pulumi.azurenative.managednetworkfabric.inputs.ActionIpCommunityPropertiesArgs.builder()
            .add(add?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .delete(delete?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .`set`(`set`?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [ActionIpCommunityPropertiesArgs].
 */
@PulumiTagMarker
public class ActionIpCommunityPropertiesArgsBuilder internal constructor() {
    private var add: Output<IpCommunityIdListArgs>? = null

    private var delete: Output<IpCommunityIdListArgs>? = null

    private var `set`: Output<IpCommunityIdListArgs>? = null

    /**
     * @param value IP Community ID list properties.
     */
    @JvmName("mmoevckxicmrgamm")
    public suspend fun add(`value`: Output<IpCommunityIdListArgs>) {
        this.add = value
    }

    /**
     * @param value IP Community ID list properties.
     */
    @JvmName("gdhqsrmkovwcteie")
    public suspend fun delete(`value`: Output<IpCommunityIdListArgs>) {
        this.delete = value
    }

    /**
     * @param value IP Community ID list properties.
     */
    @JvmName("rumearumlbyrqpat")
    public suspend fun `set`(`value`: Output<IpCommunityIdListArgs>) {
        this.`set` = value
    }

    /**
     * @param value IP Community ID list properties.
     */
    @JvmName("vnserdviabiedyea")
    public suspend fun add(`value`: IpCommunityIdListArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.add = mapped
    }

    /**
     * @param argument IP Community ID list properties.
     */
    @JvmName("kpqwsmftmtytdajh")
    public suspend fun add(argument: suspend IpCommunityIdListArgsBuilder.() -> Unit) {
        val toBeMapped = IpCommunityIdListArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.add = mapped
    }

    /**
     * @param value IP Community ID list properties.
     */
    @JvmName("enhrlkfevowbbknp")
    public suspend fun delete(`value`: IpCommunityIdListArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.delete = mapped
    }

    /**
     * @param argument IP Community ID list properties.
     */
    @JvmName("lcbdhucgvilhbdjx")
    public suspend fun delete(argument: suspend IpCommunityIdListArgsBuilder.() -> Unit) {
        val toBeMapped = IpCommunityIdListArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.delete = mapped
    }

    /**
     * @param value IP Community ID list properties.
     */
    @JvmName("crbasipenkfxtvyv")
    public suspend fun `set`(`value`: IpCommunityIdListArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`set` = mapped
    }

    /**
     * @param argument IP Community ID list properties.
     */
    @JvmName("hvsbpinmlhayqljn")
    public suspend fun `set`(argument: suspend IpCommunityIdListArgsBuilder.() -> Unit) {
        val toBeMapped = IpCommunityIdListArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.`set` = mapped
    }

    internal fun build(): ActionIpCommunityPropertiesArgs = ActionIpCommunityPropertiesArgs(
        add = add,
        delete = delete,
        `set` = `set`,
    )
}
